Description: North Dakota Supreme Court Opinions by month

May 2013
May 28, 2013
Matthew Larson Trust Agreement, 2013 ND 85
A trust may be reformed when there is clear and convincing evidence that both the settlor's intent and the terms of the trust were affected by a mistake of fact or law, whether in expression or inducement.
A mistake in the inducement occurs when the terms of the trust accurately reflect what the settlor intended to be included or excluded but this intention was based on a mistake of fact or law.
May 23, 2013
Disciplinary Board v. Triplett, 2013 ND 84
Lawyer reprimanded.
May 20, 2013
Olson v. Estate of Rustad, 2013 ND 83
A wrongful death action accrues at the time of the death of the party injured while a survival action accrues at the time the deceased was first injured.
A wrongful death action and a survival action which sound in tort are claims subject to the nonclaim provisions of the Probate Code.
A personal representative need not give actual notice by mail of the notice to creditors to those with mere conjectural claims.
The Probate Code nonclaim statute does not divest a court of jurisdiction over untimely filed claims.
A nonclaim statute, by definition, is a law that sets a time limit for creditors to bring claims against a decedent's estate, and unlike a statute of limitations, a nonclaim statute is usually not subject to tolling and is not waivable.
The nonclaim statute under the Probate Code cannot be tolled during a person's minority.
Interpretation of an insurance contract is a question of law fully reviewable on appeal, and the Supreme Court independently examines and construes the insurance contract to determine coverage.
May 17, 2013
Chambering of Judgeship No. 10 in the Northwest Judicial District, 2013 ND 82
New judgeship to be chambered in Williston.
May 16, 2013
Chambering of Judgeship No. 9 in the East Central Judicial District, 2013 ND 81
New judgeship to be chambered in Fargo.
May 14, 2013
Bachmeier v. Bachmeier, 2013 ND 76
An otherwise valid parenting plan that was attached to the judgment will not be invalidated because the district court did not recite formulaic words of incorporation.
A court order must be sufficiently clear, specific, and unambiguous to hold a person in contempt for violating it.
City of Grafton v. Wosick, 2013 ND 74
No obvious error is shown when the defendant anticipated the charge and prepared for trial accordingly.
The purpose of N.D.R.Ev. 707(a) is to ensure a defendant has an opportunity to object and confront witnesses.
A party failing to object to admission of evidence when offered may not challenge its admission on appeal.
Dieterle v. Dieterle, 2013 ND 71
A district court need not make separate findings of fact for each of the best-interest factors, a court's findings regarding one factor may be applicable to another factor, and a court need not consider irrelevant factors in its decision on primary residential responsibility for a child.
Allowing neutral individuals to resolve disputes between the parties, so long as access by the parties to the district court is allowed for ultimate resolution of the dispute, is not an improper delegation of judicial power.
Adverse rulings alone are not evidence of judicial bias or partiality.
Appellate briefs must contain references to the evidentiary record supporting statements of disputed facts.
Ennen v. State, 2013 ND 66
An appeal from an order denying an application for post-conviction relief is summarily affirmed under N.D.R.App.P. 35.1(a)(2).
Gadeco v. Industrial Commission, 2013 ND 72
The Industrial Commission has discretion to evaluate compliance with the requirements for an invitation to participate in the costs of drilling a well.
An election to participate in the costs of drilling a well must be received by the owner giving the invitation to participate within 30 days of the participating party's receipt of the invitation.
Interest of Hoff, 2013 ND 68
A district court's decision whether to require an individual to be restrained during a civil commitment proceeding is reviewed for an abuse of discretion.
An individualized determination that restraints are necessary must be made after an individual requests that the restraints be removed. Restraints should not exceed what the particular situation requires.
The determination whether restraints are necessary requires an individualized determination on the record of the individual's record, temperament, and desperateness of his situation; the security situation at the courtroom and courthouse; the individual's physical condition; and whether there was an adequate means of providing security that was less prejudicial.
A district court abuses its discretion when it fails to make an independent assessment whether to require an individual to remain restrained during a civil commitment hearing.
Interest of J.P., 2013 ND 65
Juvenile court judgments terminating a mother's parental rights are summarily affirmed under N.D.R.App.P. 35.1(a)(2) and (4).
Interest of S.R.B., 2013 ND 75
In an expedited appeal taken from an order for hospitalization and treatment, a trial court must make findings of fact specially under N.D.R.Civ.P. 52(a) as to whether the respondent is a person requiring treatment and hospitalization is the least restrictive treatment.
A mental health patient has the right to notice and a hearing prior to the trial court's issuing an order requiring the use of prescribed medication.
Jassek v. Workforce Safety and Insurance, 2013 ND 69
A binding dispute resolution decision under N.D.C.C. 65-02-20 requested by a medical provider concerning a request for treatment is not appealable to the district court.
Johnson v. Bronson, 2013 ND 78
A prima facie case of medical negligence requires expert evidence establishing the applicable standard of care, violation of that standard, and a causal relationship between the violation and the harm complained of.
The elements of a legal malpractice action against an attorney for professional negligence are [1] the existence of an attorney-client relationship, [2] a duty by the attorney to the client, [3] a breach of that duty by the attorney, and [4] damages to the client proximately caused by the breach of that duty.
Generally, expert testimony is necessary to establish the professional's standard of care (duty) and whether the professional's conduct in a particular case deviated from that standard of care (breach of duty).
The untimely submission of additional evidence to support a N.D.R.Civ.P. 60(b) motion does not create exceptional circumstances justifying relief.
Maddock v. Andersen, 2013 ND 80
Violation of the reasonable use rule cannot be established where the source of surface water drainage cannot be conclusively shown.
Northern Oil & Gas, Inc. v. Creighton, 2013 ND 73
Deciding an issue on a motion for summary judgment is not appropriate if there are disputed factual issues or if reasonable differences of opinion exist as to the inferences to be drawn from the undisputed facts.
Reformation of a contract is not permitted if it cannot be done without prejudice to the rights acquired by a third person in good faith and for value.
A good-faith purchaser must acquire rights without actual or constructive notice of another's rights.
State v. Estrada, 2013 ND 79
A modified self-defense jury instruction if, when considered with all jury instructions given as a whole, adequately informs the jury of the applicable law is not obvious error.
State v. Romero, 2013 ND 77
Allowing the jury to view the scene of a charged offense rests in the trial court's sound discretion.
A motion for judgment of acquittal must be denied if, upon reviewing the evidence most favorable to the prosecution, there is substantial evidence upon which a reasonable mind could find guilt beyond a reasonable doubt.
Steen v. State, 2013 ND 67
Appeal from order denying application for post-conviction relief summarily affirmed under N.D.R.App.P. 35.1(a)(6).
Waslaski v. State, 2013 ND 64
A district court judgment summarily dismissing a petition for post-conviction relief is summarily affirmed under N.D.R.App.P. 35.1(a)(6) and (7).
Waslaski v. State, 2013 ND 70
A motion for reconsideration is not a formally recognized motion and is not one of the enumerated appealable orders.
In appropriate circumstances, a motion for reconsideration may be treated as a motion to alter or amend a judgment or a motion for relief from a judgment or order.